import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getAllProjects } from '@/api/base'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    projects: [], // 项目列表
    activeProject: {} // 当前激活的项目
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setProject(state, projects) {
      state.projects = projects
    },
    setProjects(state, projects) {
      state.projects = projects
    },
    setActiveProjedct(state, project = {}) {
      state.activeProject = project
      localStorage.setItem('project_tag', project.tag || '')
    }
  },
  actions: {
    // 获取所有项目列表
    getAllProjects({ commit }) {
      getAllProjects().then(res => {
        const projects = res.data
        const localProjectTag = localStorage.getItem('project_tag')
        // 当前激活的项目
        if (localProjectTag) {
          const activeProject = projects.find(item => item.tag === localProjectTag) || {}
          commit('setActiveProjedct', activeProject)
        }
        // 所有项目列表
        commit('setProjects', projects)
      })
    },
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    async checkLogin({ commit }) {
      const isLogin = await getUser()
        .then(response => {
          if (response.code === 0) {
            commit('setUser', response.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      return isLogin
    }
  }
})

const localProjectTag = localStorage.getItem('project_tag')
// 当前激活的项目
if (localProjectTag) {
  store.commit('setActiveProjedct', { tag: localProjectTag })
}

// 初始化获取项目列表
store.dispatch('getAllProjects')

export default store
